"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const NbDiff_1 = require("./NbDiff");
const coreutils_1 = require("@jupyterlab/coreutils");
/**
 * A registry which maintains mappings of file extension to diff provider components.
 */
const DIFF_PROVIDER_REGISTRY = {
    '.ipynb': NbDiff_1.NBDiff
};
/**
 * Determines if a given file is supported for diffs.
 *
 * This will be removed when "Plaintext" diffs are supported since that will be used
 * for cases where there is not a dedicated diff provider.
 *
 * @param path the file path
 */
function isDiffSupported(path) {
    return coreutils_1.PathExt.extname(path).toLocaleLowerCase() in DIFF_PROVIDER_REGISTRY;
}
exports.isDiffSupported = isDiffSupported;
/**
 * The parent diff component which maintains a registry of various diff providers.
 * Based on the extension of the file, it delegates to the relevant diff provider.
 */
function Diff(props) {
    const fileExtension = coreutils_1.PathExt.extname(props.path).toLocaleLowerCase();
    if (fileExtension in DIFF_PROVIDER_REGISTRY) {
        const DiffProvider = DIFF_PROVIDER_REGISTRY[fileExtension];
        return React.createElement(DiffProvider, Object.assign({}, props));
    }
    else {
        // This will be removed and delegated to a "Plaintext" diff provider for
        // cases where the file extension does not have a dedicated diff provider.
        console.log(`Diff is not supported for ${fileExtension} files`);
        return null;
    }
}
exports.Diff = Diff;
const renderMimeContext = React.createContext(null);
exports.RenderMimeProvider = renderMimeContext.Provider;
exports.RenderMimeConsumer = renderMimeContext.Consumer;
